# Welcome to MkDocs

For full documentation visit [mkdocs.org](https://www.mkdocs.org).

## Commands

* `mkdocs new [dir-name]` - Create a new project.
* `mkdocs serve` - Start the live-reloading docs server.
* `mkdocs build` - Build the documentation site.
* `mkdocs -h` - Print help message and exit.

## Project layout

    mkdocs.yml    # The configuration file.
    docs/
        index.md        # The documentation homepage.
        feature_matrix.md # Supported features comparison.
        inputs.md       # Guide to using inputs.
        classes.md      # Class reference.
        options.md      # Options documentation.
        admin.md        # Admin documentation.

## User Guides

*   [Feature Matrix](feature_matrix.md): See what FormKit features are supported.
*   [Inputs Guide](inputs.md): Learn how to use standard and pro inputs.
*   [Class Reference](classes.md): Technical documentation for key classes.
